// **********************************************************************
//
// Copyright (c) 2003-2007 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

using System;
using System.Reflection;
using System.Runtime.CompilerServices;

[assembly: CLSCompliant(true)]

[assembly: AssemblyTitle("generatecs")]
[assembly: AssemblyDescription("Make-like program to compile Slice files")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("ZerocC, Inc.")]
[assembly: AssemblyProduct("Ice for C# Pre-Build Event Program")]
[assembly: AssemblyCopyright("Copyright (c) 2003-2007, ZeroC, Inc.")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
[assembly: AssemblyVersion("1.0")]
[assembly: AssemblyDelaySign(false)]
